/*
 * Copyright (c) 2022 Shaburov Oleg
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR
 * ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package org.touchbit.qa.automatron.resource;

import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.actuate.endpoint.web.annotation.RestControllerEndpoint;
import org.springframework.http.HttpStatus;
import org.springframework.http.RequestEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PatchMapping;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.touchbit.qa.automatron.constant.ConfigParameter;
import org.touchbit.qa.automatron.pojo.admin.ConfigDTO;
import org.touchbit.qa.automatron.service.ConfigService;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;
import java.util.Map;
import java.util.Objects;
import java.util.Set;
import java.util.stream.Collectors;

import static org.springframework.http.MediaType.APPLICATION_JSON_VALUE;

@Slf4j
@AllArgsConstructor
@RestControllerEndpoint(id = "config")
public class ConfigurationActuatorApiController {

    private final ConfigService confService;

    @ResponseStatus(HttpStatus.OK)
    @GetMapping(path = "/", produces = APPLICATION_JSON_VALUE)
    public Map<ConfigParameter, ConfigDTO> getConfiguration() {
        final Set<ConfigDTO> configs = confService.getConfiguration();
        return toMap(configs);
    }

    @ResponseStatus(HttpStatus.OK)
    @PatchMapping(path = "/", produces = APPLICATION_JSON_VALUE, consumes = APPLICATION_JSON_VALUE)
    public Map<ConfigParameter, ConfigDTO> updateConfig(RequestEntity<@Valid @NotNull ConfigDTO> value) {
        confService.updateConfig(Objects.requireNonNull(value.getBody()));
        final Set<ConfigDTO> configs = confService.getConfiguration();
        return toMap(configs);
    }

    private Map<ConfigParameter, ConfigDTO> toMap(Set<ConfigDTO> configs) {
        return confService.getConfiguration().stream()
                .collect(Collectors.toMap(ConfigDTO::parameterName, c -> c));
    }

}
